# tc_mailmanager
ToucanToco's cross-python-projects MailManager

## Installation

You need :
- git installed
- an SSH key authorized for toucantoco's private github repos

Replace `1.1.3` with the git tag you want :

```bash
$ pip install -e 'git+ssh://git@github.com/toucantoco/tc_mailmanager@1.1.3#egg=tc_mailmanager'
```

Or put `-e git+ssh://git@github.com/toucantoco/tc_mailmanager@1.1.3#egg=tc_mailmanager` in your `requirements.txt`
